/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the ContextMenu Extensions.
 *
 * The Initial Developer of the Original Code is SHIMODA Hiroshi.
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): SHIMODA Hiroshi <piro@p.club.ne.jp>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
// static class "JSPanelService" 
var JSPanelService = {

	utils : ExtCommonUtils,
	
	get tabs() 
	{
		return document.getElementById('scriptPageTabs');
	},
	get tabpanels()
	{
		return document.getElementById('scriptPagePanels');
	},
 
	get script() 
	{
		return this.scripts[this.tabs.selectedIndex];
	},
 
	get scripts() 
	{
		return document.getElementsByTagName('textbox');
	},
 
	get status() 
	{
		return document.getElementById('statusbar');
	},
 
	init : function() 
	{
		var tabs   = this.tabs,
			label  = tabs.getAttribute('labelTemplate'),
			panels = this.tabpanels,
			max    = this.utils.getPref('ctxextensions.JSPanel.page.number');
		for (var i = 1; i < max; i++)
		{
			tabs.appendChild(document.createElement('tab'));
			tabs.lastChild.label = label.replace(/%s/gi, i+1);

			panels.appendChild(panels.firstChild.cloneNode(true));
			panels.lastChild.lastChild.id = 'script'+(i+1);
		}
		tabs.firstChild.label = label.replace(/%s/gi, 1);

		tabs.selectedIndex = this.utils.getPref('ctxextensions.JSPanel.page.last') || 0 ;

		document.documentElement.getButton('extra1').label = document.getElementById('extra1-label').getAttribute('label');

		this.loadScript();
		this.script.focus();
		this.utils.doCommand(this.script, 'cmd_moveTop');
	},
	
	saveScript : function() 
	{
		var scripts = this.scripts;
		for (var i = 0; i < scripts.length; i++)
		{
			if (scripts[i].value)
				this.utils.setPref('ctxextensions.JSPanel.history.page'+i, scripts[i].value, true);
			else
				this.utils.clearPref('ctxextensions.JSPanel.history.page'+i);
		}
	},
 
	loadScript : function() 
	{
		var scripts = this.scripts;
		for (var i = 0; i < scripts.length; i++)
			scripts[i].value = this.utils.getPref('ctxextensions.JSPanel.history.page'+i, true) || '';
	},
  
	// XNvg̑ 
	
	runScript : function() 
	{
		this.clearStatus()

		var script = this.script.value;
		if (!script.replace(/\s/gi, '')) return;

		if (!this.utils.browserWindow) {
			this.status.label = this.utils.getMsg('JSPanel_WindowOpen');
			var w = window.openDialog(this.utils.browserURI, '_blank', 'chrome,all,dialog=no');
			var progress = new pProgressManager(this.runScriptObserver, 50/*, w*/);
			progress.appendItem(w, script, window);
			progress.start();
		}
		else {
			this.utils.browserWindow.ExtFunc.CustomScripts(null, script);
//			this.script.focus();
			window.focus();
			this.status.label = this.utils.getMsg('JSPanel_OK');
		}

		return;
	},
	
	runScriptObserver : 
	{
		onProgress : function(aManager, aWindow, aScript, aJSPanel)
		{
			if (!aWindow || ('closed' in aWindow && aWindow.closed))
				return true;

			if (!('ExtService' in aWindow) ||
				!aWindow.ExtService.initialized) return false;

			aWindow.ExtFunc.CustomScripts(null, aScript);
//			JSPanelService.script.focus();
			aJSPanel.focus();
			return true;
		},
		onProgressEnd : function(aManager)
		{
			JSPanelService.status.label = JSPanelService.utils.getMsg('JSPanel_OK');
		}
	},
  
	importScript : function() 
	{
		var file = this.utils.chooseFile(
			this.utils.getMsg('filePicker_title_javascript'),
			null,
			[
				this.utils.getMsg('filePicker_filter_javascript'),
				'*.js'
			]
		);
		if (!file) return;

		var content = this.utils.readFrom(file);

		this.script.focus();

		if (content) {
			this.script.value = content;
			this.utils.doCommand(this.script, 'cmd_moveTop');
		}
		return;
	},
 
	clearScript : function() 
	{
		this.utils.doCommand(this.script, 'cmd_selectAll');
		this.utils.doCommand(this.script, 'cmd_delete');
		this.script.focus();
	},
  
	clearStatus : function() 
	{
		this.status.label = '';
	},
 
	destruct : function() 
	{
		this.saveScript();
		this.utils.setPref('ctxextensions.JSPanel.page.last', this.tabs.selectedIndex);
	}
};
  
